# LlamaIndex Agent Integration: DashScope

> DashScopeAgent is powered by the [Alibaba ModelStudio Platform](https://www.aliyun.com/product/bailian).

- Users can configure the LLM, system instructions, and various plugins such as knowledge retrieval and web search.
- To get started, you need to create an agent application on the ModelStudio Platform and publish it.
- Once the application is published, you can interact with the agent using the DashScopeAgent API.
